package org.jeecg.modules.commCity.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.commCity.entity.CommCity;
import org.jeecg.modules.commCity.service.ICommCityService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 城市列表
 * @Author: jeecg-boot
 * @Date:   2024-12-05
 * @Version: V1.0
 */
@Api(tags="城市列表")
@RestController
@RequestMapping("/commCity/commCity")
@Slf4j
public class CommCityController extends JeecgController<CommCity, ICommCityService>{
	@Autowired
	private ICommCityService commCityService;
	
	/**
	 * 分页列表查询
	 *
	 * @param commCity
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "城市列表-分页列表查询")
	@ApiOperation(value="城市列表-分页列表查询", notes="城市列表-分页列表查询")
	@GetMapping(value = "/rootList")
	public Result<IPage<CommCity>> queryPageList(CommCity commCity,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		String hasQuery = req.getParameter("hasQuery");
        if(hasQuery != null && "true".equals(hasQuery)){
            QueryWrapper<CommCity> queryWrapper =  QueryGenerator.initQueryWrapper(commCity, req.getParameterMap());
            List<CommCity> list = commCityService.queryTreeListNoPage(queryWrapper);
            IPage<CommCity> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        }else{
            String parentId = commCity.getPid();
            if (oConvertUtils.isEmpty(parentId)) {
                parentId = "0";
            }
            commCity.setPid(null);
            QueryWrapper<CommCity> queryWrapper = QueryGenerator.initQueryWrapper(commCity, req.getParameterMap());
            // 使用 eq 防止模糊查询
            queryWrapper.eq("pid", parentId);
            Page<CommCity> page = new Page<CommCity>(pageNo, pageSize);
            IPage<CommCity> pageList = commCityService.page(page, queryWrapper);
            return Result.OK(pageList);
        }
	}

	 /**
      * 获取子数据
      * @param commCity
      * @param req
      * @return
      */
	//@AutoLog(value = "城市列表-获取子数据")
	@ApiOperation(value="城市列表-获取子数据", notes="城市列表-获取子数据")
	@GetMapping(value = "/childList")
	public Result<IPage<CommCity>> queryPageList(CommCity commCity,HttpServletRequest req) {
		QueryWrapper<CommCity> queryWrapper = QueryGenerator.initQueryWrapper(commCity, req.getParameterMap());
		List<CommCity> list = commCityService.list(queryWrapper);
		IPage<CommCity> pageList = new Page<>(1, 10, list.size());
        pageList.setRecords(list);
		return Result.OK(pageList);
	}

    /**
      * 批量查询子节点
      * @param parentIds 父ID（多个采用半角逗号分割）
      * @return 返回 IPage
      * @param parentIds
      * @return
      */
	//@AutoLog(value = "城市列表-批量获取子数据")
    @ApiOperation(value="城市列表-批量获取子数据", notes="城市列表-批量获取子数据")
    @GetMapping("/getChildListBatch")
    public Result getChildListBatch(@RequestParam("parentIds") String parentIds) {
        try {
            QueryWrapper<CommCity> queryWrapper = new QueryWrapper<>();
            List<String> parentIdList = Arrays.asList(parentIds.split(","));
            queryWrapper.in("pid", parentIdList);
            List<CommCity> list = commCityService.list(queryWrapper);
            IPage<CommCity> pageList = new Page<>(1, 10, list.size());
            pageList.setRecords(list);
            return Result.OK(pageList);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            return Result.error("批量查询子节点失败：" + e.getMessage());
        }
    }
	
	/**
	 *   添加
	 *
	 * @param commCity
	 * @return
	 */
	@AutoLog(value = "城市列表-添加")
	@ApiOperation(value="城市列表-添加", notes="城市列表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CommCity commCity) {
		commCityService.addCommCity(commCity);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param commCity
	 * @return
	 */
	@AutoLog(value = "城市列表-编辑")
	@ApiOperation(value="城市列表-编辑", notes="城市列表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CommCity commCity) {
		commCityService.updateCommCity(commCity);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "城市列表-通过id删除")
	@ApiOperation(value="城市列表-通过id删除", notes="城市列表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		commCityService.deleteCommCity(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "城市列表-批量删除")
	@ApiOperation(value="城市列表-批量删除", notes="城市列表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.commCityService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "城市列表-通过id查询")
	@ApiOperation(value="城市列表-通过id查询", notes="城市列表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CommCity> queryById(@RequestParam(name="id",required=true) String id) {
		CommCity commCity = commCityService.getById(id);
		if(commCity==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(commCity);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param commCity
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CommCity commCity) {
		return super.exportXls(request, commCity, CommCity.class, "城市列表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
		return super.importExcel(request, response, CommCity.class);
    }

}
