package org.jeecg.modules.commonAccount.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.commonAccount.entity.CommonAccount;
import org.jeecg.modules.commonAccount.service.ICommonAccountService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 账号信息表
 * @Author: jeecg-boot
 * @Date:   2024-12-07
 * @Version: V1.0
 */
@Api(tags="账号信息表")
@RestController
@RequestMapping("/commonAccount/commonAccount")
@Slf4j
public class CommonAccountController extends JeecgController<CommonAccount, ICommonAccountService> {
	@Autowired
	private ICommonAccountService commonAccountService;
	
	/**
	 * 分页列表查询
	 *
	 * @param commonAccount
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "账号信息表-分页列表查询")
	@ApiOperation(value="账号信息表-分页列表查询", notes="账号信息表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CommonAccount>> queryPageList(CommonAccount commonAccount,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CommonAccount> queryWrapper = QueryGenerator.initQueryWrapper(commonAccount, req.getParameterMap());
		Page<CommonAccount> page = new Page<CommonAccount>(pageNo, pageSize);
		IPage<CommonAccount> pageList = commonAccountService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param commonAccount
	 * @return
	 */
	@AutoLog(value = "账号信息表-添加")
	@ApiOperation(value="账号信息表-添加", notes="账号信息表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CommonAccount commonAccount) {
		//根据账号查询当前账号是否存在
		QueryWrapper<CommonAccount> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("account",commonAccount.getAccount());
		List<CommonAccount> list = commonAccountService.list(queryWrapper);
		if(list.size()>0){
			return Result.error("账号已存在");
		}
		//授权码已存在
		QueryWrapper<CommonAccount> queryWrapper1 = new QueryWrapper<>();
		queryWrapper1.eq("invoice",commonAccount.getInvoice());
		List<CommonAccount> list1 = commonAccountService.list(queryWrapper1);
		if(list1.size()>0){
			return Result.error("授权码已存在");
		}
		//根据用户标识查询该用户是否已经存在
		QueryWrapper<CommonAccount> queryWrapper2 = new QueryWrapper<>();
		queryWrapper2.eq("user_id",commonAccount.getUserId());
		List<CommonAccount> list2 = commonAccountService.list(queryWrapper2);
		if(list2.size()>0){
			return Result.error("该用户已存在");
		}
		commonAccountService.save(commonAccount);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param commonAccount
	 * @return
	 */
	@AutoLog(value = "账号信息表-编辑")
	@ApiOperation(value="账号信息表-编辑", notes="账号信息表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CommonAccount commonAccount) {
		//根据账号查询当前账号是否存在
		QueryWrapper<CommonAccount> queryWrapper = new QueryWrapper<>();
		queryWrapper.eq("account",commonAccount.getAccount());
		List<CommonAccount> list = commonAccountService.list(queryWrapper);
		if(list.size()>0){
			return Result.error("账号已存在");
		}
		commonAccountService.updateById(commonAccount);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "账号信息表-通过id删除")
	@ApiOperation(value="账号信息表-通过id删除", notes="账号信息表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		commonAccountService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "账号信息表-批量删除")
	@ApiOperation(value="账号信息表-批量删除", notes="账号信息表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.commonAccountService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "账号信息表-通过id查询")
	@ApiOperation(value="账号信息表-通过id查询", notes="账号信息表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CommonAccount> queryById(@RequestParam(name="id",required=true) String id) {
		CommonAccount commonAccount = commonAccountService.getById(id);
		if(commonAccount==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(commonAccount);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param commonAccount
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CommonAccount commonAccount) {
        return super.exportXls(request, commonAccount, CommonAccount.class, "账号信息表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CommonAccount.class);
    }

}
